# SpiderMatch

[![image](https://img.shields.io/pypi/v/spidermatch.svg)](https://pypi.python.org/pypi/spidermatch) [![Bundle App](https://github.com/agucova/spidermatch/actions/workflows/main.yml/badge.svg)](https://github.com/agucova/spidermatch/actions/workflows/main.yml)

![](spidermatch/assets/logo_dark.png#gh-dark-mode-only)
![](spidermatch/assets/logo_light.png#gh-light-mode-only)


> **Note**
> This app is currently available in Spanish only. An Eglish version is coming soon.

An open-source app for setting up search engine lookups for incidents covered by local news in a certain country. This app is used for criminology research in policing.

## Installation
The app is available on PyPI, so you can install it with pip:

```bash
pip install spidermatch
```

Bundled version of the apps are also available for Windows, Linux and macOS (unsigned).
You can find them in the [releases](https://github.com/agucova/spidermatch/releases) section.

## Usage

This app integrates with ZenSerp, a search engine API. You will need to create an account and get an API key. You can do so [here](https://zenserp.com/).

## Contributing
See [CONTRIBUTING.md](CONTRIBUTING.md).

## License
This project is licensed under the terms of the [GPLv3](https://www.gnu.org/licenses/gpl-3.0.html) license. See [LICENSE](LICENSE) for more information.
